==> zio-aws-codecommit_2.12-5.17.151.2-sources.jar: zio/aws/codecommit/model/MergeBranchesBySquashResponse.scala <==
package zio.aws.codecommit.model
import zio.aws.codecommit.model.primitives.ObjectId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class MergeBranchesBySquashResponse(
    commitId: Option[ObjectId] = None,
    treeId: Option[ObjectId] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codecommit.model.MergeBranchesBySquashResponse = {
    import MergeBranchesBySquashResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codecommit.model.MergeBranchesBySquashResponse
      .builder()
      .optionallyWith(
        commitId.map(value => ObjectId.unwrap(value): java.lang.String)
      )(_.commitId)
      .optionallyWith(
        treeId.map(value => ObjectId.unwrap(value): java.lang.String)
      )(_.treeId)
      .build()
  }
  def asReadOnly
      : zio.aws.codecommit.model.MergeBranchesBySquashResponse.ReadOnly =
    zio.aws.codecommit.model.MergeBranchesBySquashResponse.wrap(buildAwsValue())
}
object MergeBranchesBySquashResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codecommit.model.MergeBranchesBySquashResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codecommit.model.MergeBranchesBySquashResponse =
      zio.aws.codecommit.model.MergeBranchesBySquashResponse(
        commitId.map(value => value),
        treeId.map(value => value)
      )
    def commitId: Option[ObjectId]
    def treeId: Option[ObjectId]
    def getCommitId: ZIO[Any, AwsError, ObjectId] =
      AwsError.unwrapOptionField("commitId", commitId)
    def getTreeId: ZIO[Any, AwsError, ObjectId] =
      AwsError.unwrapOptionField("treeId", treeId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codecommit.model.MergeBranchesBySquashResponse
  ) extends zio.aws.codecommit.model.MergeBranchesBySquashResponse.ReadOnly {
    override val commitId: Option[ObjectId] = scala
      .Option(impl.commitId())
      .map(value => zio.aws.codecommit.model.primitives.ObjectId(value))
    override val treeId: Option[ObjectId] = scala
      .Option(impl.treeId())
      .map(value => zio.aws.codecommit.model.primitives.ObjectId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codecommit.model.MergeBranchesBySquashResponse
  ): zio.aws.codecommit.model.MergeBranchesBySquashResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-codecommit_2.13-5.19.31.3-sources.jar: zio/aws/codecommit/model/MergeBranchesBySquashResponse.scala <==
package zio.aws.codecommit.model
import zio.aws.codecommit.model.primitives.ObjectId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class MergeBranchesBySquashResponse(
    commitId: Optional[ObjectId] = Optional.Absent,
    treeId: Optional[ObjectId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codecommit.model.MergeBranchesBySquashResponse = {
    import MergeBranchesBySquashResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codecommit.model.MergeBranchesBySquashResponse
      .builder()
      .optionallyWith(
        commitId.map(value => ObjectId.unwrap(value): java.lang.String)
      )(_.commitId)
      .optionallyWith(
        treeId.map(value => ObjectId.unwrap(value): java.lang.String)
      )(_.treeId)
      .build()
  }
  def asReadOnly
      : zio.aws.codecommit.model.MergeBranchesBySquashResponse.ReadOnly =
    zio.aws.codecommit.model.MergeBranchesBySquashResponse.wrap(buildAwsValue())
}
object MergeBranchesBySquashResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codecommit.model.MergeBranchesBySquashResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codecommit.model.MergeBranchesBySquashResponse =
      zio.aws.codecommit.model.MergeBranchesBySquashResponse(
        commitId.map(value => value),
        treeId.map(value => value)
      )
    def commitId: Optional[ObjectId]
    def treeId: Optional[ObjectId]
    def getCommitId: ZIO[Any, AwsError, ObjectId] =
      AwsError.unwrapOptionField("commitId", commitId)
    def getTreeId: ZIO[Any, AwsError, ObjectId] =
      AwsError.unwrapOptionField("treeId", treeId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codecommit.model.MergeBranchesBySquashResponse
  ) extends zio.aws.codecommit.model.MergeBranchesBySquashResponse.ReadOnly {
    override val commitId: Optional[ObjectId] = zio.aws.core.internal
      .optionalFromNullable(impl.commitId())
      .map(value => zio.aws.codecommit.model.primitives.ObjectId(value))
    override val treeId: Optional[ObjectId] = zio.aws.core.internal
      .optionalFromNullable(impl.treeId())
      .map(value => zio.aws.codecommit.model.primitives.ObjectId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codecommit.model.MergeBranchesBySquashResponse
  ): zio.aws.codecommit.model.MergeBranchesBySquashResponse.ReadOnly =
    new Wrapper(impl)
}
